==> MiningMart-1.0-src.zip: MiningMart-1.0/src/edu/udo/cs/miningmart/m4/ColumnsetStatistics.java <==
/*
 * MiningMart Version 1.0
 * 
 * Copyright (C) 2006 Martin Scholz, Timm Euler, 
 *                    Daniel Hakenjos, Katharina Morik
 *
 * Contact: miningmart@ls8.cs.uni-dortmund.de
 *
 * A list of contributing developers (other than the copyright 
 * holders) can be found at
 * http://mmart.cs.uni-dortmund.de/downloads/download.html
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program, see the file MM_HOME/LICENSE; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 */
package edu.udo.cs.miningmart.m4;

import edu.udo.cs.miningmart.exception.M4Exception;

/**
 * @author Timm Euler
 * @version $Id: ColumnsetStatistics.java,v 1.3 2006/04/11 14:10:12 euler Exp $
 */
public interface ColumnsetStatistics extends M4Object {

  Columnset getTheColumnset();

  void setTheColumnset(Columnset columnSet) throws M4Exception;

  Integer getNrOfAllTuples();

  void setNrOfAllTuples(Integer nrOfRows);

  Integer getNrOfOrdAttribs();

  void setNrOfOrdAttribs(Integer nrOfOrdinalAttributes);

  Integer getNrOfNomAttribs();

  void setNrOfNomAttribs(Integer nrOfNominalAttributes);

  Integer getNrOfTimeAttribs();

  void setNrOfTimeAttribs(Integer nrOfTimeAttributes);
}
/*
 * Historie
 * --------
 * 
 * $Log: ColumnsetStatistics.java,v $
 * Revision 1.3  2006/04/11 14:10:12  euler
 * Updated license text.
 *
 * Revision 1.2  2006/04/06 16:31:12  euler
 * Prepended license remark.
 *
 * Revision 1.1  2006/01/03 09:54:23  hakenjos
 * Initial version!
 *
 */

==> MiningMart-1.1-src.zip: MiningMart-1.1/src/edu/udo/cs/miningmart/m4/ColumnsetStatistics.java <==
/*
 * MiningMart Version 1.1
 * 
 * Copyright (C) 2006 Martin Scholz, Timm Euler, 
 *                    Daniel Hakenjos, Katharina Morik
 *
 * Contact: miningmart@ls8.cs.uni-dortmund.de
 *
 * A list of contributing developers (other than the copyright 
 * holders) can be found at
 * http://mmart.cs.uni-dortmund.de/downloads/download.html
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program, see the file MM_HOME/LICENSE; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 */
package edu.udo.cs.miningmart.m4;

import edu.udo.cs.miningmart.exception.M4Exception;

/**
 * @author Timm Euler
 * @version $Id: ColumnsetStatistics.java,v 1.4 2006/09/27 14:59:58 euler Exp $
 */
public interface ColumnsetStatistics extends M4Object {

  Columnset getTheColumnset();

  void setTheColumnset(Columnset columnSet) throws M4Exception;

  Long getNrOfAllTuples();

  void setNrOfAllTuples(Long nrOfRows);

  Integer getNrOfOrdAttribs();

  void setNrOfOrdAttribs(Integer nrOfOrdinalAttributes);

  Integer getNrOfNomAttribs();

  void setNrOfNomAttribs(Integer nrOfNominalAttributes);

  Integer getNrOfTimeAttribs();

  void setNrOfTimeAttribs(Integer nrOfTimeAttributes);
}
/*
 * Historie
 * --------
 * 
 * $Log: ColumnsetStatistics.java,v $
 * Revision 1.4  2006/09/27 14:59:58  euler
 * New version 1.1
 *
 * Revision 1.3  2006/04/11 14:10:12  euler
 * Updated license text.
 *
 * Revision 1.2  2006/04/06 16:31:12  euler
 * Prepended license remark.
 *
 * Revision 1.1  2006/01/03 09:54:23  hakenjos
 * Initial version!
 *
 */
